﻿using System.Collections.Generic;
using System.Collections.ObjectModel;
using System.Windows;
using ThinkGeo.MapSuite;
using ThinkGeo.MapSuite.Drawing;
using ThinkGeo.MapSuite.Layers;
using ThinkGeo.MapSuite.Shapes;
using ThinkGeo.MapSuite.Styles;
using ThinkGeo.MapSuite.Wpf;

namespace _9114
{
    /// <summary>
    /// Interaction logic for MainWindow.xaml
    /// </summary>
    public partial class MainWindow : Window
    {
        public MainWindow()
        {
            InitializeComponent();
        }

        private void map_Loaded(object sender, RoutedEventArgs e)
        {
            map.MapUnit = GeographyUnit.DecimalDegree;


            LayerOverlay layerOverlay = new LayerOverlay();

            InMemoryFeatureLayer layer = new InMemoryFeatureLayer();
            layer.ZoomLevelSet.ZoomLevel01.CustomStyles.Add(new PolePointstyle());
            layer.ZoomLevelSet.ZoomLevel01.ApplyUntilZoomLevel = ApplyUntilZoomLevel.Level20;

            Feature f1 = new Feature(10, 10);
            f1.ColumnValues.Add("has_panel", "true");

            layer.InternalFeatures.Add(f1);

            layerOverlay.Layers.Add(layer);
            map.Overlays.Add(layerOverlay);

            layer.Open();
            map.CurrentExtent = layer.GetBoundingBox();
            map.Refresh();
        }
    }

    public class PolePointstyle : PointBaseStyle
    {
        protected override void DrawCore(IEnumerable<Feature> features, GeoCanvas canvas, Collection<SimpleCandidate> labelsInThisLayer, Collection<SimpleCandidate> labelsInAllLayers)
        {
            foreach (Feature feature in features)
            {
                PointStyle style = GetPointStyle(feature);
                style.Draw(new Collection<Feature>() { feature }, canvas, labelsInThisLayer, labelsInAllLayers);
            }
        }

        private PointStyle GetPointStyle(Feature feature)
        {
            bool hasPanel;
            bool.TryParse(feature.ColumnValues["has_panel"].ToString(), out hasPanel);
            var poleStyle = hasPanel ? PointStyles.CreateSimpleTriangleStyle(GeoColor.StandardColors.Red, 10, GeoColor.StandardColors.Black, 1) : PointStyles.CreateSimpleCircleStyle(GeoColor.StandardColors.Blue, 10, GeoColor.StandardColors.Black, 1);
            /*Other processing */
            return poleStyle;
        }
    }
}
